==> haskell-safecopy-0.9.4.3-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-safecopy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: safecopy
version: 0.9.4.3
id: safecopy-0.9.4.3-IeE5vFZQ9LWHj7PlcmqnQy
key: safecopy-0.9.4.3-IeE5vFZQ9LWHj7PlcmqnQy
license: LicenseRef-PublicDomain
maintainer: Lemmih <lemmih@gmail.com>
author: David Himmelstrup, Felipe Lessa
homepage: https://github.com/acid-state/safecopy
synopsis: Binary serialization with version control.
description:
    An extension to Data.Serialize with built-in version control.
category: Data, Parsing
abi: ed688ad0e0ed76dd36e477149808dac9
exposed: True
exposed-modules:
    Data.SafeCopy Data.SafeCopy.Internal
hidden-modules: Data.SafeCopy.Instances Data.SafeCopy.SafeCopy
                Data.SafeCopy.Derive
import-dirs: /usr/lib/ghc-8.6.5/site-local/safecopy-0.9.4.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/safecopy-0.9.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/safecopy-0.9.4.3
hs-libraries: HSsafecopy-0.9.4.3-IeE5vFZQ9LWHj7PlcmqnQy
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2
    cereal-0.5.8.0-DifhRWa8By0JYDe2id7eOT containers-0.6.0.1
    old-time-1.1.0.3-HsoRJMkCHriE79r63Cxfu4 template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-safecopy/html/safecopy.haddock
haddock-html: /usr/share/doc/haskell-safecopy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-safecopy-0.9.4.3-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-safecopy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: safecopy
version: 0.9.4.3
id: safecopy-0.9.4.3-IsZsBi0JtN20UBWj6hQMG
key: safecopy-0.9.4.3-IsZsBi0JtN20UBWj6hQMG
license: LicenseRef-PublicDomain
maintainer: Lemmih <lemmih@gmail.com>
author: David Himmelstrup, Felipe Lessa
homepage: https://github.com/acid-state/safecopy
synopsis: Binary serialization with version control.
description:
    An extension to Data.Serialize with built-in version control.
category: Data, Parsing
abi: 55bfa2ad853be03e4a2ea62835eb23c6
exposed: True
exposed-modules:
    Data.SafeCopy Data.SafeCopy.Internal
hidden-modules: Data.SafeCopy.Instances Data.SafeCopy.SafeCopy
                Data.SafeCopy.Derive
import-dirs: /usr/lib/ghc-8.6.5/site-local/safecopy-0.9.4.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/safecopy-0.9.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/safecopy-0.9.4.3
hs-libraries: HSsafecopy-0.9.4.3-IsZsBi0JtN20UBWj6hQMG
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2
    cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh containers-0.6.0.1
    old-time-1.1.0.3-HsoRJMkCHriE79r63Cxfu4 template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-safecopy/html/safecopy.haddock
haddock-html: /usr/share/doc/haskell-safecopy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
